package com.brettstevens.gymdiary;

import java.util.List;

import com.brettstevens.gymdiary.db.Db;

import android.app.Activity;
import android.app.AlertDialog;
import android.content.DialogInterface;
import android.content.Intent;
import android.os.Bundle;
import android.view.Menu;
import android.view.View;
import android.widget.ArrayAdapter;
import android.widget.Button;
import android.widget.Spinner;
import android.widget.TextView;
 
public class AddExerciseEntryActivity extends Activity {
	//Initialize database
	private Db gymDiaryDb = new Db(this);
	
    @Override
    
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_db_add_entry);
        // Container that keeps the intent and various information
        final Bundle applicationBundle = getIntent().getExtras();
        //Sets up name label , and set the text of the label to what ever exercise was scanned
        TextView nameLabel = (TextView) findViewById(R.id.addEntryNameLabel);
        nameLabel.setText(applicationBundle.getString("name"));
        
        //Creates a new array to store 10 strings
        String[] sets = new String[10];
        //add 1 - 10
        for (int i = 1; i < 11; i++) {
        	sets[i-1] = String.valueOf(i);
        }
        //add 1-25
        String[] repetitions = new String[25];
        
        for (int i = 1; i < 26; i++) {
        	repetitions[i-1] = String.valueOf(i);
        }
        //add 0.5-300
        String[] weight = new String[600];
       
        Double weightTotal = 0.5;
        
        for (int i = 1; i < 601; i++) {
        	Double tempWeight = weightTotal;
        	weight[i - 1] = String.valueOf(tempWeight);
        	
        	//increment weight total by 0.5
        	weightTotal += 0.5;
        }
        //Sets up the dialogue ready to be shown
		final AlertDialog.Builder dialog = new AlertDialog.Builder(this);
		dialog.setTitle("Success");
		dialog.setMessage("Entry was successfully added\nPress OK to return to the home screen");
		dialog.setPositiveButton("OK", new DialogInterface.OnClickListener() {
		      public void onClick(DialogInterface dialog, int which) {
		    	  Intent goHome = new Intent(getApplicationContext(), MainActivity.class);
		    	  //clearing the current stack on return to home screen(clears history)
		    	  goHome.setFlags(Intent.FLAG_ACTIVITY_NEW_TASK | Intent.FLAG_ACTIVITY_CLEAR_TOP);
		    	  startActivity(goHome);
		    	  //complete this activity
		    	  finish();
		      } 
		});
        //Assigning the spinner to varibles that we can use later
        final Spinner setsSpinner = (Spinner) findViewById(R.id.addEntrySetsSpinner);
        final Spinner repsSpinner = (Spinner) findViewById(R.id.addEntryRepsSpinner);
        final Spinner weightSpinner = (Spinner) findViewById(R.id.addEntryWeightSpinner);
        
        //Containers that hold the values of the spinners
        ArrayAdapter<String> setsAdapter = new ArrayAdapter<String>(this, android.R.layout.simple_spinner_item, sets);
        ArrayAdapter<String> repsAdapter = new ArrayAdapter<String>(this, android.R.layout.simple_spinner_item, repetitions);
        ArrayAdapter<String> weightAdapter = new ArrayAdapter<String>(this, android.R.layout.simple_spinner_item, weight);
        
        //Setting the drop down view of the spinner
        setsAdapter.setDropDownViewResource(android.R.layout.simple_spinner_dropdown_item);
        repsAdapter.setDropDownViewResource(android.R.layout.simple_spinner_dropdown_item);
        weightAdapter.setDropDownViewResource(android.R.layout.simple_spinner_dropdown_item);
        
        //Adding the values to the spinners
        setsSpinner.setAdapter(setsAdapter);
        repsSpinner.setAdapter(repsAdapter);
        weightSpinner.setAdapter(weightAdapter);
        
        //assign the button to a variable (add entry)
        final Button addExercise = (Button) findViewById(R.id.addEntryButton);
        
        //Sets listener on the button
        addExercise.setOnClickListener(
			new View.OnClickListener() {	
				@Override
				public void onClick(View v) {
					//Uses TagID to get exercise ID from Database
					List<String> exerciseId = gymDiaryDb.getIdFromTagId((applicationBundle.getInt("tagId")));
					
					//If the database returns one entry, add entry to the database based on selected values
					if(exerciseId.size() == 1) {
						
						//If an entry is added to the database, display dialog 
						if(gymDiaryDb.addEntry(exerciseId.get(0), setsSpinner.getSelectedItem().toString(), repsSpinner.getSelectedItem().toString(), weightSpinner.getSelectedItem().toString(), applicationBundle.getString("dateAdded"))) {
							dialog.show();
						}
					}
				}
			}
        );
    }

    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        // Inflate the menu; this adds items to the action bar if it is present.
        getMenuInflater().inflate(R.menu.main, menu);
        return true;
    }
}
