package com.brettstevens.gymdiary;

import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Calendar;
import java.util.Date;
import java.util.HashMap;
import java.util.List;

import com.brettstevens.gymdiary.db.Db;

import android.annotation.SuppressLint;
import android.app.Activity;
import android.app.AlertDialog;
import android.content.DialogInterface;
import android.content.Intent;
import android.os.Bundle;
import android.util.Log;
import android.view.Menu;
import android.view.View;
import android.widget.ArrayAdapter;
import android.widget.Button;
import android.widget.Spinner;
import android.widget.Toast;

//
public class AddExerciseEntryManualActivity extends Activity {
	
	//Initialize database and global variables
	private HashMap<String, String> listOfAllExercises;
	private Db gymDiaryDb = new Db(this);
	private String date = "";
	
    @SuppressLint("SimpleDateFormat")
	@Override
	
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_db_add_entry_manual);
        
        // Container that keeps the intent and various information
        final Bundle applicationBundle = getIntent().getExtras();

        String from = applicationBundle.getString("from");
        
        //Checks to see if from is equal to "cal"  
        if(from.equals("cal")) {
        	
        	//this is error messages used for debugging
        	Log.d("GymDiary", "Sent from CalendarView");
        	Calendar selectedDate = Calendar.getInstance();
        	
        	//Take date year, month and day from calendar view
			selectedDate.set(Calendar.YEAR, applicationBundle.getInt("year"));
			selectedDate.set(Calendar.MONTH, applicationBundle.getInt("month"));
			selectedDate.set(Calendar.DAY_OF_MONTH, applicationBundle.getInt("day"));
		
			//Formats date for database insertion , if not sent from calendar view , adds with current date
			date = new SimpleDateFormat("dd-MM-yyyy HH:mm:ss").format(selectedDate.getTime());
        } else {
        	date = new SimpleDateFormat("dd-MM-yyyy HH:mm:ss").format(new Date());
        }
        
        //debug message
        Log.d("GymDiary", date);
        
        //Setting string 1- 10
        String[] sets = new String[10];
        
        for (int i = 1; i < 11; i++) {
        	sets[i-1] = String.valueOf(i);
        }
        
        //setting string size 1 - 25
        String[] repetitions = new String[25];
        
        for (int i = 1; i < 26; i++) {
        	repetitions[i-1] = String.valueOf(i);
        }
        
        //add 0.5-300
        String[] weight = new String[600];
        
        Double weightTotal = 0.5;
        
        
        for (int i = 1; i < 601; i++) {
        	Double tempWeight = weightTotal;
        	weight[i - 1] = String.valueOf(tempWeight);
        	//increment weight total by 0.5
        	weightTotal += 0.5;
        }
        
        //Sets up the dialogue ready to be shown
		final AlertDialog.Builder dialog = new AlertDialog.Builder(this);
		dialog.setTitle("Success");
		dialog.setMessage("Entry was successfully added\nPress OK to return to the home screen");
		dialog.setPositiveButton("OK", new DialogInterface.OnClickListener() {
		      public void onClick(DialogInterface dialog, int which) {
		    	  Intent goHome = new Intent(getApplicationContext(), MainActivity.class);
		    	  
		    	  //clearing the current stack on return to home screen(clears history)
		    	  goHome.setFlags(Intent.FLAG_ACTIVITY_NEW_TASK | Intent.FLAG_ACTIVITY_CLEAR_TOP);
		    	  startActivity(goHome);
		    	
		    	  //complete this activity
		    	  finish();
		      } 
		});
		//get all exercises from database 
        listOfAllExercises = gymDiaryDb.getExercises();
        
        //Creates list of exercises 
        List<String> exerciseList = new ArrayList<String>();
        
        //debug message
        Log.d("GymDiary", "Enumerating values from keys");
        
        
        for (String key : listOfAllExercises.keySet()) {
        	exerciseList.add(key);
        }
        
      //debug message
        Log.d("GymDiary", "Setting spinners");
        
      //Assigning the spinner to varibles that we can use later
        final Spinner setsSpinner = (Spinner) findViewById(R.id.addEntryManualSetsSpinner);
        final Spinner repsSpinner = (Spinner) findViewById(R.id.addEntryManualRepsSpinner);
        final Spinner weightSpinner = (Spinner) findViewById(R.id.addEntryManualWeightSpinner);
        final Spinner exercisesSpinner = (Spinner) findViewById(R.id.addEntryManualExerciseSpinner);
        
        //debug message
        Log.d("GymDiary", "Setting adapters");
        
        //Containers that hold the values of the spinners
        ArrayAdapter<String> setsAdapter = new ArrayAdapter<String>(this, android.R.layout.simple_spinner_item, sets);
        ArrayAdapter<String> repsAdapter = new ArrayAdapter<String>(this, android.R.layout.simple_spinner_item, repetitions);
        ArrayAdapter<String> weightAdapter = new ArrayAdapter<String>(this, android.R.layout.simple_spinner_item, weight);
        ArrayAdapter<String> exerciseAdapter = new ArrayAdapter<String>(this, android.R.layout.simple_spinner_item, exerciseList);
        
        //debug message
        Log.d("GymDiary", "Setting drop down views");
        
        //Setting the drop down view of the spinner
        setsAdapter.setDropDownViewResource(android.R.layout.simple_spinner_dropdown_item);
        repsAdapter.setDropDownViewResource(android.R.layout.simple_spinner_dropdown_item);
        weightAdapter.setDropDownViewResource(android.R.layout.simple_spinner_dropdown_item);
        exerciseAdapter.setDropDownViewResource(android.R.layout.simple_spinner_dropdown_item);
        
        //debug message
        Log.d("GymDiary", "Adding adapters to spinners");
        
        //Adding the values to the spinners
        setsSpinner.setAdapter(setsAdapter);
        repsSpinner.setAdapter(repsAdapter);
        weightSpinner.setAdapter(weightAdapter);
        exercisesSpinner.setAdapter(exerciseAdapter);
        
        //assign the button to a variable (add entry manual)
        final Button addExercise = (Button) findViewById(R.id.addEntryManualButton);
        
        //add listener to button
        addExercise.setOnClickListener(
			new View.OnClickListener() {	
				@Override
				public void onClick(View v) {
					
					String exerciseNameText = exercisesSpinner.getSelectedItem().toString();
					
					//If true populate the spinner else display error message
					if(gymDiaryDb.addEntry(listOfAllExercises.get(exerciseNameText), setsSpinner.getSelectedItem().toString(), repsSpinner.getSelectedItem().toString(), weightSpinner.getSelectedItem().toString(), date)) {
							dialog.show();
					} else {
						toast("Something went wrong whilst adding the entry to the database");
					}
				}
			}
        );
    }
    
    protected void toast(String message) {
    	//setup toast
    	Toast.makeText(this, new String(message), Toast.LENGTH_SHORT).show();
    }

    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        // Inflate the menu; this adds items to the action bar if it is present.
        getMenuInflater().inflate(R.menu.main, menu);
        return true;
    }
}
