package com.brettstevens.gymdiary;

import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Calendar;
import java.util.HashMap;
import java.util.List;

import android.annotation.SuppressLint;
import android.app.Activity;
import android.app.AlertDialog;
import android.content.DialogInterface;
import android.content.Intent;
import android.os.Bundle;
import android.util.Log;
import android.view.Menu;
import android.view.View;
import android.view.View.OnLongClickListener;
import android.widget.AdapterView;
import android.widget.AdapterView.OnItemLongClickListener;
import android.widget.ArrayAdapter;
import android.widget.CalendarView;
import android.widget.CalendarView.OnDateChangeListener;
import android.widget.ListView;
import android.widget.Toast;

import com.brettstevens.gymdiary.db.Db;


public class CalendarActivity extends Activity {
	
	//Initialize database and various variables 
	protected Db gymDiaryDb = new Db(this);
	protected ArrayList<HashMap<String, String>> exerciseOnDayArrayList;
	protected int currentlySelectedDay;
	protected int currentlySelectedMonth;
	protected int currentlySelectedYear;
	protected String idToDelete = "";
	
    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_calendar);
        
        //Get list of all entries 
        ArrayList<HashMap<String, String>> allEntries = gymDiaryDb.getEntries();
        
        //Prints out list of entries in debug
        for (HashMap<String, String> hash : allEntries) {
        	Log.d("GymDiary", "id: " + hash.get("id") + " exercise_id: " + hash.get("exercise_id") + " sets: " + hash.get("sets") + " repetitions: " + hash.get("repetitions") + " weight: " + hash.get("weight") + " date_added: " + hash.get("date_added"));
        }
        
        //create calendar 
        CalendarView calendar = (CalendarView) findViewById(R.id.calendarView);
        Calendar currentDate = Calendar.getInstance();

        //popluate list with todays exercises 
        populateList(currentDate.get(currentDate.DAY_OF_MONTH), currentDate.get(currentDate.MONTH), currentDate.get(currentDate.YEAR), false);
        
        //sets up the dialog ready to be shown 
        final AlertDialog.Builder addEntryDialog = new AlertDialog.Builder(this);
		addEntryDialog.setTitle("Add Entry");
		addEntryDialog.setMessage("Do you want to add an entry for " + intToDate(currentlySelectedYear, currentlySelectedMonth, currentlySelectedDay) + "?");
		addEntryDialog.setPositiveButton("Yes", new DialogInterface.OnClickListener() {
			public void onClick(DialogInterface dialog, int which) {
				Intent changeToManualEntryView = new Intent(getApplicationContext(), AddExerciseEntryManualActivity.class);
				
				//sends currently selected date
				changeToManualEntryView.putExtra("from", "cal");
				changeToManualEntryView.putExtra("year", currentlySelectedYear);
				changeToManualEntryView.putExtra("month", currentlySelectedMonth);
				changeToManualEntryView.putExtra("day", currentlySelectedDay);
				startActivityForResult(changeToManualEntryView, 0);
		    } 
		});
		//On no , do nothing
		addEntryDialog.setNegativeButton("No", new DialogInterface.OnClickListener() {
			public void onClick(DialogInterface dialog, int which) {
				
			}
		});
        
        //creates listener on long click(in calendar view)
        calendar.setOnLongClickListener(new OnLongClickListener() {
			@Override
			public boolean onLongClick(View v) {
				//On long click display dialog included selected date
				addEntryDialog.setMessage("Do you want to add an entry for " + intToDate(currentlySelectedYear, currentlySelectedMonth, currentlySelectedDay) + "?");
				addEntryDialog.show();
				return true;
			}
        });
        
        //whens date changes re-populate list with current selected date
        calendar.setOnDateChangeListener(new OnDateChangeListener() {
        	public void onSelectedDayChange(CalendarView view, int year, int month, int dayOfMonth) {
        		populateList(dayOfMonth, month, year, false);
        	}
        });
        
        //Sets dialog if row is deleted returns message "exercise deleted" if not "failed to delete exercise"
		final AlertDialog.Builder dialog = new AlertDialog.Builder(this);
		dialog.setTitle("Delete Entry");
		dialog.setMessage("Are you sure you want to delete the selected entry?");
		dialog.setPositiveButton("Yes", new DialogInterface.OnClickListener() {
		      public void onClick(DialogInterface dialog, int which) {
		    	if(gymDiaryDb.removeEntry(idToDelete) > 0) {
		    		toast("Exercise deleted");
		    		populateList(currentlySelectedDay, currentlySelectedMonth, currentlySelectedYear, true);
		    	} else {
					toast("Failed to delete exercise");
				}

		      } 
		});
		//If no, do nothing
		dialog.setNegativeButton("No", new DialogInterface.OnClickListener() {
			public void onClick(DialogInterface dialog, int which) {
				
			}
		});
		
        //If long click in calendar view 
        final ListView list = (ListView) findViewById(R.id.dailyExerciseList);
        list.setLongClickable(true);
        
        //Sets Listener for long click
        list.setOnItemLongClickListener(new OnItemLongClickListener() {
            public boolean onItemLongClick(AdapterView<?> arg0, View arg1, int position, long id) {
            	
            	//gets ID from the array for the record that needs to be deleted , and shows in the dialog
            	HashMap<String, String> tempHash = exerciseOnDayArrayList.get(position);
            	idToDelete = tempHash.get(list.getItemAtPosition(position));
            	dialog.show();
                return true;
            }
        });
    }

    @SuppressLint("SimpleDateFormat")
    
    //if the day has'nt changed and no over ride don't change, else re-populate the list  
	protected void populateList(int day, int month, int year, Boolean override) {
    	if(day == currentlySelectedDay && month == currentlySelectedMonth && year == currentlySelectedYear && !override) {
    		
    	} else {
    		currentlySelectedDay = day;
    		currentlySelectedMonth = month;
    		currentlySelectedYear = year;
    		
    		Calendar date = Calendar.getInstance();
    		
    		date.set(Calendar.YEAR, year);
    		date.set(Calendar.MONTH, month);
    		date.set(Calendar.DAY_OF_MONTH, day);
    		
    		String selectedDate = new SimpleDateFormat("dd-MM-yyyy").format(date.getTime());
    		
    		//debug message
    		Log.d("GymDiary", selectedDate);
    		
    		ListView list = (ListView) findViewById(R.id.dailyExerciseList);
    		
    		//add entries from database added that day
    		exerciseOnDayArrayList = gymDiaryDb.getEntriesOnDate(selectedDate);
    		List<String> exerciseOnDay = new ArrayList<String>();
    		
    		//loops through all the hash's and gets the keys
    		for(HashMap<String, String> hash : exerciseOnDayArrayList) {
    			for(String key : hash.keySet()) {
    				exerciseOnDay.add(key);
    			}
    		}
    		
    		//debug message 
    		Log.d("GymDiary", String.valueOf(exerciseOnDay.size()));
    		
    		//if records added set container if not set to null (display shows nothing)
    		if(exerciseOnDay.size() > 0) {
    			list.setAdapter(new ArrayAdapter<String>(this, android.R.layout.simple_list_item_1, exerciseOnDay));
    		} else {
    			list.setAdapter(null);
    		}
    	}
    	
    }
    
    //If 3 numbers are parsed it returns in simple date format 
    protected String intToDate(int year, int month, int day) {
    	
		Calendar date = Calendar.getInstance();
		
		date.set(Calendar.YEAR, year);
		date.set(Calendar.MONTH, month);
		date.set(Calendar.DAY_OF_MONTH, day);
		
		String selectedDate = new SimpleDateFormat("dd/MM/yyyy").format(date.getTime());
    	
		//debug messages
		Log.d("GymDiary", String.valueOf(year));
		Log.d("GymDiary", String.valueOf(month));
		Log.d("GymDiary", String.valueOf(day));
		Log.d("GymDiary", selectedDate);
		
    	return selectedDate;
    }
    //toast method
    protected void toast(String message) {
    	Toast.makeText(this, new String(message), Toast.LENGTH_SHORT).show();
    }
    
    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        // Inflate the menu; this adds items to the action bar if it is present.
        getMenuInflater().inflate(R.menu.main, menu);
        return true;
    }
}