package com.brettstevens.gymdiary;

import java.util.HashMap;
import java.util.List;

import com.brettstevens.gymdiary.R;
import com.brettstevens.gymdiary.db.Db;
import com.brettstevens.gymdiary.nfc.*;
import android.nfc.NfcAdapter;
import android.os.Bundle;
import android.app.Activity;
import android.app.PendingIntent;
import android.content.Intent;
import android.util.Log;
import android.view.Menu;
import android.view.View;
import android.widget.Button;
import android.widget.TextView;
import android.widget.Toast;

public class NFCActivity extends Activity {
	//Set up variable for use later
    private TextView textView;
    private NfcAdapter NFCAdapter;
    private PendingIntent NFCTagPendingIntent;
    private Db gymDiaryDb = new Db(this);
    private int tagId = -1;
    private String name = "";
    private String dateAdded = "";
    
    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_nfc);
       
        //Set textView to our label
        textView = (TextView) findViewById(R.id.checkNfcAdapterTextMain);
        
        //Get and initialise NFC adapter from phone
        NFCAdapter = NfcAdapter.getDefaultAdapter(this);
        
        //Check if we have got an adapter and set text to indicate
        if(NFCAdapter == null) {
        	textView.setText("Unable to enable NFC adapter");
        }
        
        // Create and intent for tag data
        NFCTagPendingIntent = PendingIntent.getActivity(this, 0, new Intent(this, getClass()).addFlags(Intent.FLAG_ACTIVITY_SINGLE_TOP), 0);
        
        final Button goToAddExerciseEntry = (Button) findViewById(R.id.addActivityFromTagButton);
        
        goToAddExerciseEntry.setOnClickListener(
			new View.OnClickListener() {	
				@Override
				public void onClick(View v) {
					Intent changeToAddExerciseEntryView = new Intent(v.getContext(), AddExerciseEntryActivity.class);
					changeToAddExerciseEntryView.putExtra("tagId", tagId);
					changeToAddExerciseEntryView.putExtra("name", name);
					changeToAddExerciseEntryView.putExtra("dateAdded", dateAdded);
					startActivityForResult(changeToAddExerciseEntryView, 0);
				}
			}
        );
    }
    
    @Override
    public void onNewIntent(Intent intent) {
    	
    	//Initialise reader and pass it the intent to parse
    	NFCReader reader = new NFCReader();
    	HashMap<String, String> result = reader.getTag(intent);
    	Boolean showButton = false;
    	
    	final Button addActivityFromTagButton = (Button) findViewById(R.id.addActivityFromTagButton);
    	
    	if(result.get("payload") == "-1") {
    		textView.setText("Empty or unrecognisable tag scanned -- Please try again");
    		addActivityFromTagButton.setVisibility(View.INVISIBLE);
    	} else {
    		String[] values = result.get("payload").split(";");
    		if(values.length == 2) {
    			textView.setText(values[1]);
    			List<String> checkForExercise = gymDiaryDb.checkForTagId(Integer.valueOf(values[0]));
    			Log.d("GymDiary-Size", String.valueOf(checkForExercise.size()));
    			
    			if(checkForExercise.size() == 0) {
    				toast("New exercise scanned, adding " + values[1] + " to database");
    				
    				if(gymDiaryDb.addExercise(values[1], Integer.valueOf(values[0]))) {
    					toast("Successfully added " + values[1] + " to database");
    					showButton = true;
    					tagId = Integer.valueOf(values[0]);
    					name = values[1];
    					dateAdded = result.get("dateRead");
    				} else {
    					toast("Something went wrong whilst adding " + values[1] + " to the database");
    				}
    			} else if (checkForExercise.size() == 1) {
    				showButton = true;
    				tagId = Integer.valueOf(values[0]);
    				name = values[1];
    				dateAdded = result.get("dateRead");
    			}
    		} else {
    			showButton = false;
    			textView.setText(result.get("payload"));
    			toast("Malformed Gym Diary tag detected.\nPayload: " + result.get("payload"));
    		}
    	}
    	
    	if(showButton) {
    		addActivityFromTagButton.setVisibility(View.VISIBLE);
    	} else {
    		addActivityFromTagButton.setVisibility(View.INVISIBLE);
    	}
    	
    }

    protected void toast(String message) {
    	Toast.makeText(this, new String(message), Toast.LENGTH_SHORT).show();
    }
    
    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        // Inflate the menu; this adds items to the action bar if it is present.
        getMenuInflater().inflate(R.menu.main, menu);
        return true;
    }
    
    
    @Override
    public void onResume() {
        super.onResume();
 
        //If we have NFC capability, enable foreground dispatch with the pending intent
        if (NFCAdapter != null) {
            NFCAdapter.enableForegroundDispatch(this, NFCTagPendingIntent, null, null);
        }
    }
 
    @Override
    public void onPause() {
        super.onPause();
 
        //If we have NFC capability, disable foreground dispatch
        if (NFCAdapter != null) {
            NFCAdapter.disableForegroundDispatch(this);
        }
    }
}