package com.brettstevens.gymdiary.db;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;

import android.content.ContentValues;
import android.content.Context;
import android.database.Cursor;
import android.database.sqlite.SQLiteDatabase;
import android.database.sqlite.SQLiteOpenHelper;
import android.util.Log;

public class Db extends SQLiteOpenHelper {
	private static final String GymDiary = null;

	public Db(Context application) {
        super(application, "gymdiary.db", null, 1);
        Log.d(GymDiary,"Created");
    }
	
	@Override
	public void onCreate(SQLiteDatabase gymDiaryDatabase) {
		String query;
		query = "CREATE TABLE \"exercises\" (\"id\" INTEGER PRIMARY KEY  AUTOINCREMENT  NOT NULL  UNIQUE , \"name\" TEXT NOT NULL  UNIQUE , \"tag_id\" INTEGER UNIQUE )";
        gymDiaryDatabase.execSQL(query);
        Log.d(GymDiary,"Exercises table added");
        query = "CREATE TABLE \"entries\" (\"id\" INTEGER PRIMARY KEY  AUTOINCREMENT  NOT NULL  UNIQUE , \"exercise_id\" INTEGER NOT NULL , \"sets\" INTEGER NOT NULL , \"repetitions\" INTEGER NOT NULL , \"weight\" DOUBLE NOT NULL , \"date_added\" DATETIME NOT NULL )";
        gymDiaryDatabase.execSQL(query);
        
        ContentValues values = new ContentValues();
        
        values.put("name", "Bench press");
        values.put("tag_id", "1");
        gymDiaryDatabase.insert("exercises", null, values);
        
        values = new ContentValues();
        
        values.put("name", "Deadlift");
        values.put("tag_id", "2");
        gymDiaryDatabase.insert("exercises", null, values);
        
        Log.d(GymDiary,"Entries table added");
	}
	@Override
	public void onUpgrade(SQLiteDatabase gymDiaryDatabase, int old, int current) {
		String query;
		query = "DROP TABLE IF EXISTS exercises";
		gymDiaryDatabase.execSQL(query);
		query = "DROP TABLE IF EXISTS entries";
		gymDiaryDatabase.execSQL(query);
        onCreate(gymDiaryDatabase);
	}
	
	public Boolean addExercise(String name, int tagId) {
		SQLiteDatabase database = this.getWritableDatabase();
		ContentValues values = new ContentValues();
		
		Boolean success = false;
		
		values.put("name", name);
		if(tagId != -1) {
			values.put("tag_id", tagId);
		} else {
			values.put("tag_id", (String) null);
		}
		
		if(database.insert("exercises", null, values) != -1) {
			success = true;
		}
		database.close();
		Log.d("GymDiary", "Added " + name);
		
		return success;
	}
	
	public Boolean addEntry(String exerciseId, String sets, String reps, String weight, String dateAdded) {
		SQLiteDatabase database = this.getWritableDatabase();
		ContentValues values = new ContentValues();
		
		Boolean success = false;
		
		values.put("exercise_id", exerciseId);
		values.put("sets", sets);
		values.put("repetitions", reps);
		values.put("weight", weight);
		values.put("date_added", dateAdded);
		
		if(database.insert("entries", null, values) != -1) {
			success = true;
		}
		database.close();
		Log.d("GymDiary", "Added entry");
		
		return success;
	}
	
	public HashMap<String, String> getExercises() {
		Log.d("GymDiary", "Getting all exercises");
		HashMap<String, String> listOfAllExercises = new HashMap<String, String>();
		String query = "SELECT  * FROM exercises";
	    SQLiteDatabase database = this.getWritableDatabase();
	    Cursor cursor = database.rawQuery(query, null);
	    
	    if (cursor.moveToFirst()) {
	        do {
	        	listOfAllExercises.put(cursor.getString(1), cursor.getString(0));
	        } while (cursor.moveToNext());
	    }
	    
	    Log.d("GymDiary", "Returning all exercises");
	    return listOfAllExercises;
	}
	
	public HashMap<String, String> getExercise(int id) {
		HashMap<String, String> exercise = new HashMap<String, String>();
		SQLiteDatabase database = this.getReadableDatabase();
		String selectQuery = "SELECT * FROM exercises where id='"+ Integer.toString(id) + "'";
		Cursor cursor = database.rawQuery(selectQuery, null);
		if (cursor.moveToFirst()) {
	        do {
					//HashMap<String, String> map = new HashMap<String, String>();
	        	exercise.put("id", cursor.getString(0));
	        	exercise.put("name", cursor.getString(1));
	        	exercise.put("tag_id", cursor.getString(2));
				   //wordList.add(map);
	        } while (cursor.moveToNext());
	    }				    
		return exercise;
	}
	
	public List<String> checkForTagId(int id) {
		List<String> exercise = new ArrayList<String>();
		SQLiteDatabase database = this.getReadableDatabase();
		String selectQuery = "SELECT tag_id FROM exercises where tag_id='"+ Integer.toString(id) + "'";
		Cursor cursor = database.rawQuery(selectQuery, null);
		if (cursor.moveToFirst()) {
	        do {
	        	exercise.add(cursor.getString(0));
	        } while (cursor.moveToNext());
	    }				    
		return exercise;
	}	
	
	public List<String> getIdFromTagId(int id) {
		List<String> exercise = new ArrayList<String>();
		SQLiteDatabase database = this.getReadableDatabase();
		String selectQuery = "SELECT id FROM exercises where tag_id='"+ Integer.toString(id) + "'";
		Cursor cursor = database.rawQuery(selectQuery, null);
		if (cursor.moveToFirst()) {
	        do {
	        	exercise.add(cursor.getString(0));
	        } while (cursor.moveToNext());
	    }				    
		return exercise;
	}
	
	public ArrayList<HashMap<String, String>> getEntriesOnDate(String date) {
		ArrayList<HashMap<String, String>> exercise = new ArrayList<HashMap<String, String>>();
		SQLiteDatabase database = this.getReadableDatabase();
		String selectQuery = "SELECT exercises.name, entries.sets, entries.repetitions, entries.weight, entries.id FROM entries, exercises WHERE entries.date_added BETWEEN '" + date + " 00:00:00.00' AND '" + date + " 23:59:59.999' AND entries.exercise_id = exercises.id";
		Cursor cursor = database.rawQuery(selectQuery, null);
		if (cursor.moveToFirst()) {
	        do {
	        	HashMap<String, String> hash = new HashMap<String, String>();
	        	hash.put(cursor.getString(0) + "\n\tSets: " + cursor.getString(1) + "\n\tReps: " + cursor.getString(2) + "\n\tWeight: " + cursor.getString(3) + "Kg", cursor.getString(4));
	        	exercise.add(hash);
	        } while (cursor.moveToNext());
	    }				    
		return exercise;
	}
	
	public ArrayList<HashMap<String, String>> getEntries() {
		Log.d("GymDiary", "Getting all entries");
		ArrayList<HashMap<String, String>> listOfAllEntries = new ArrayList<HashMap<String, String>>();
		String query = "SELECT  * FROM entries";
	    SQLiteDatabase database = this.getWritableDatabase();
	    Cursor cursor = database.rawQuery(query, null);
	    
	    if (cursor.moveToFirst()) {
	        do {
	        	HashMap<String, String> hash = new HashMap<String, String>();
	        	hash.put("id", cursor.getString(0));
	        	hash.put("exercise_id", cursor.getString(1));
	        	hash.put("sets", cursor.getString(2));
	        	hash.put("repetitions", cursor.getString(3));
	        	hash.put("weight", cursor.getString(4));
	        	hash.put("date_added", cursor.getString(5));
	        	listOfAllEntries.add(hash);
	        } while (cursor.moveToNext());
	    }
	    
	    Log.d("GymDiary", "Returning all exercises");
	    return listOfAllEntries;
	}
	
	public int removeExercise(int id) {
		SQLiteDatabase database = this.getWritableDatabase();	 
		String query = "DELETE FROM entries WHERE exercise_id = '" + Integer.toString(id) + "'";
		database.rawQuery(query, null);
		return database.delete("exercises", "id = " + Integer.toString(id), null);
	}
	
	public int removeEntry(String id) {
		SQLiteDatabase database = this.getWritableDatabase();	 
		return database.delete("entries", "id = " + id, null);
	}
}
