package com.brettstevens.gymdiary.nfc;

import java.text.SimpleDateFormat;
import java.util.Arrays;
import java.util.Date;
import java.util.HashMap;

import android.annotation.SuppressLint;
import android.content.Intent;
import android.nfc.NdefMessage;
import android.nfc.NdefRecord;
import android.nfc.NfcAdapter;
import android.os.Parcelable;
import android.util.Log;

public class NFCReader {
	@SuppressLint("SimpleDateFormat")
	public HashMap<String, String> getTag(Intent intent) {
		
		HashMap<String, String> result = new HashMap<String, String>();
		
		//Initialise string
        String tagText = "";
        
        //Get array of data to parse
        Parcelable[] data = intent.getParcelableArrayExtra(NfcAdapter.EXTRA_NDEF_MESSAGES);
        
        //Check if we have data payload, if not it is an empty but formatted tag
        if (data != null) {
            try {
            	//Loop through data and get stored records
                for (int i = 0; i < data.length; i++) {
                    NdefRecord [] NDEFRecords = ((NdefMessage)data[i]).getRecords();
                    
                    //Loop through record and get 
                    for (int j = 0; j < NDEFRecords.length; j++) {
                        if (NDEFRecords[j].getTnf() == NdefRecord.TNF_WELL_KNOWN && Arrays.equals(NDEFRecords[j].getType(), NdefRecord.RTD_TEXT)) {
                        	byte[] tagPayload = NDEFRecords[j].getPayload();
                        
                            /* Build string, stripping of the language identifier at the start
                             * 
                             * tagPayload[0] & 0777 gets the length of the country code identifier from the control byte
                             * tagPayload[0] & 0200 gets the bit identifying whether it is stored as UTF-8 or UTF-16 from the control byte
                             * 
                             * new String(the whole payload, start string from country code identifier +1, finish at length - country code identifier length - 1, set encoding to UTF-8 or UTF-16 depending on control byte
                             */
                            tagText = new String(tagPayload, (tagPayload[0] & 0077) + 1, tagPayload.length - (tagPayload[0] & 0077) - 1, ((tagPayload[0] & 0200) == 0) ? "UTF-8" : "UTF-16");
                        }
                    }
                }
            } catch (Exception e) {
                Log.e("TagDispatch", e.toString());
            }
        } else {
        	tagText = "";
        }
        
        result.put("payload", (tagText.isEmpty() || tagText == null) ? "-1" : tagText);
        result.put("dateRead", new SimpleDateFormat("dd-MM-yyyy HH:mm:ss").format(new Date()));

        return result;
	}
}
